<?php

namespace mofyi;

use GuzzleHttp\Client as HttpClient;

/**
 * 麦斯魔方接口请求类
 * Version 1
 */
class MiceRequest
{
    public function __construct($activity_id = '', $public_key = '', $private_key = '')
    {
        $this->publicKey = $public_key;
        $this->privateKey = $private_key;
        $this->activityId = $activity_id;
    }

    private function createAuth()
    {
        $auth = [
            'UserPublicKey' => $this->publicKey,
            'ActivityId' => $this->activityId,
            'Time' => time(),
            'Version' => 1,
            'PrivateKey' => $this->privateKey
        ];
        $signature = md5(json_encode($auth, JSON_UNESCAPED_SLASHES));

        unset($auth['PrivateKey']);
        $auth['Signature'] = $signature;

        return ['Mice-Auth' => json_encode($auth)];
    }

    /**
     * 发送请求
     *
     * @param string $uri 请求路径 例如 api/authorization/add_participants
     * @param array $data 请求数据
     * @return mixed
     */
    public function send($uri, $data)
    {
        // 获取接口验证参数
        $auth = $this->createAuth();

        $res = $this->sendRequest('POST', 'https://www.micecube.com/' . $uri, $data, ['headers' => $auth]);

        return $res;
    }

    /**
     * 发送GET或POST
     *
     * @param string $method GET或POST
     * @param string $url 请求地址
     * @param array $data 发送数据
     * @param array $options 请求选项
     * @param boolean $is_json 是否为json请求
     * @return array
     */
    private function sendRequest($method = 'GET', $url, $data = [], $options = [], $is_json = false)
    {
        if ($is_json) {
            $options['json'] = $data;
        } else {
            $options['form_params'] = $data;
        }
        $options['verify'] = false;
    
        $client = new HttpClient();
        $response = $client->request($method, $url, $options);
    
        $res = $response->getBody()->getContents();
    
        if (is_string($res)) {
            $res = json_decode($res, true);
        }
    
        return $res;
    }
}
